class ActiveRecord::Base
  # 指定された :id があれば update する。なければ create。
  def self.create_or_update(options = {})
    options = options.with_indifferent_access
    id = options.delete("id")
    record = find_by_id(id) || new
    record.id = id
    record.attributes = options
    record.save!
    
    record
  rescue ActiveRecord::ActiveRecordError => ex
    puts "ERROR: #{ex.class} : #{ex.message}"
    Rails.logger.error "ERROR: #{ex.class} : #{ex.message}"
    raise ex
  end
end

# DBマスターデータロード
require 'active_record/fixtures'
#require 'action_controller/test_process'

ActiveRecord::Base.transaction do
  (ENV['FIXTURES'] ? ENV['FIXTURES'].split(/,/) : Dir.glob(File.join(Rails.root, 'db', 'master_fixtures', '*.{yml,csv}'))).each do |fixture_file|
    tname = File.basename(fixture_file, '.*')
    table = tname.singularize.camelize.constantize
    records = YAML.load(ERB.new(IO.read(fixture_file)).result)
    puts records[Rails.env]
    records[Rails.env].each do |key, record|
      table.create_or_update(record)
    end
  end
end
